<?php
/**
 * Created by PhpStorm.
 * User: crose
 * Date: 1/28/16
 * Time: 8:05 AM
 */

namespace qfq;

require_once(__DIR__ . '/../Constants.php');

/**
 * Class HelperFile
 * @package qfq
 */
class HelperFile {

    /**
     * Iterate over array $files. Delete only named files which are stored in '/tmp/' . DOWNLOAD_FILE_PREFIX.
     *
     * @param array $files
     */
    public static function cleanTempFiles(array $files) {

        foreach ($files as $file) {
            if (self::isQfqTemp($file)) {
                unlink($file);
            }

            $dir = dirname($file);
            if (self::isQfqTemp($dir)) {
                rmdir($dir);
            }
        }
    }

    /**
     * Returns a uniqe (use for temporary) filename, prefixed with QFQ TMP_FILE_PREFIX
     *
     * @return bool|string
     */
    public static function tempnam(){
        return tempnam(sys_get_temp_dir(), TMP_FILE_PREFIX);
    }

    /**
     * Check against standard QFQ Temp location. If it is a Qfq Temp location, return true, else false.
     *
     * @param string $name Absolute filename.
     *
     * @return bool
     */
    public static function isQfqTemp($name) {
        $prefix = sys_get_temp_dir() . '/' . TMP_FILE_PREFIX;
        $len = strlen($prefix);

        return (substr($name, 0, $len) == $prefix);
    }

    /**
     * Creates a temporary directory.
     */
    public static function mktempdir() {
        $name = tempnam(sys_get_temp_dir(), TMP_FILE_PREFIX);
        unlink($name);
        mkdir($name);

        return $name;
    }

    /**
     * Return the mimetype of $pathFilename
     *
     * @param string $pathFilename
     * @param bool $flagIgnoreError
     * @return string
     * @throws UserFormException
     */
    public static function getMimeType($pathFilename, $flagIgnoreError = false) {

        // E.g.: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet; charset=binary'
        $fileMimeType = exec('file --brief --mime ' . $pathFilename, $output, $return_var);
        if ($return_var != 0) {

            if ($flagIgnoreError) {
                return '';
            }

            throw new UserFormException('Error get mime type of upload.', ERROR_UPLOAD_GET_MIME_TYPE);
        }

        return $fileMimeType;
    }

    /**
     * Returns an array with filestat information to $pathFileName
     *
     * @param $pathFileName
     * @return array
     * @throws UserFormException
     */
    public static function getFileStat($pathFileName) {
        $vars = array();

        if (empty($pathFileName)) {
            return array();
        }

        $pathFileName = self::correctRelativPathFileName($pathFileName);

        $vars[VAR_FILE_MIME_TYPE] = self::getMimeType($pathFileName);
        $vars[VAR_FILE_SIZE] = filesize($pathFileName);

        return $vars;
    }

    /**
     * Correct $pathFilename, if the cwd is .../qfq/api'
     *
     * @param $pathFileName
     * @return string
     */
    public static function correctRelativPathFileName($pathFileName) {

        if (empty($pathFileName)) {
            return '';
        }

        if ($pathFileName[0] == '/') {
            return $pathFileName;
        }

        if (substr(getcwd(), -8) == '/qfq/api') {
            return '../../../../../' . $pathFileName;
        }

        return $pathFileName;
    }

    /**
     * Split $pathFileName into it's components and fill an array, with array keys like used in STORE_VAR.
     *
     * @param string $pathFileName
     * @return array
     */
    public static function pathInfo($pathFileName) {
        $vars = array();

        $pathParts = pathinfo($pathFileName);
        $vars[VAR_FILENAME] = $pathFileName;

        if (isset($pathParts['basename'])) {
            $vars[VAR_FILENAME_ONLY] = $pathParts['basename'];
        }

        if (isset($pathParts['filename'])) {
            $vars[VAR_FILENAME_BASE] = $pathParts['filename'];
        }

        if (isset($pathParts['extension'])) {
            $vars[VAR_FILENAME_EXT] = $pathParts['extension'];
        }

        return $vars;
    }

}